==> nextcloud-22.2.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/zh_TW.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "是否要加入來自 {owner}@{remote} 的遠端分享 {name} ？",
    "Remote share" : "遠端分享",
    "Remote share password" : "遠端分享密碼",
    "Cancel" : "取消",
    "Add remote share" : "新增遠端分享",
    "Copy" : "複製",
    "Copied!" : "已複製！",
    "Not supported!" : "不支援！",
    "Press ⌘-C to copy." : "按下 ⌘-C 以複製。",
    "Press Ctrl-C to copy." : "按下 Ctrl-C 以複製。",
    "Invalid Federated Cloud ID" : "無效的雲端聯盟 ID",
    "Server to server sharing is not enabled on this server" : "伺服器對伺服器共享在這台伺服器上面並未啟用",
    "Couldn't establish a federated share." : "無法建立聯盟式分享。",
    "Couldn't establish a federated share, maybe the password was wrong." : "無法建立聯盟式分享，可能是密碼錯誤。",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "已傳送聯盟式分享請求，您將會收到邀請。請檢查您的通知。",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "無法建立聯盟式分享，看來是要聯盟的伺服器太舊了 (Nextcloud <= 9)。",
    "It is not allowed to send federated group shares from this server." : "不允許從此伺服器傳送聯盟式群組分享。",
    "Sharing %1$s failed, because this item is already shared with user %2$s" : "分享 %1$s 失敗，因為此項目已與使用者 %2$s 分享",
    "Not allowed to create a federated share with the same user" : "不允許與同一個使用者建立聯盟式分享",
    "Federated shares require read permissions" : "聯盟分享需要讀取權限",
    "File is already shared with %s" : "檔案已與 %s 分享",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "分享 %1$s 失敗，找不到 %2$s，或許伺服器目前無法存取或使用自行簽署的憑證。",
    "Could not find share" : "找不到分享",
    "Federated sharing" : "聯盟式分享",
    "You received \"%3$s\" as a remote share from %4$s (%1$s) (on behalf of %5$s (%2$s))" : "您收到了來自 %4$s (%1$s)（代表 %5$s (%2$s)）的遠端分享「%3$s」",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "您收到了來自 {user}（代表 {behalf}）的遠端分享 {share}",
    "You received \"%3$s\" as a remote share from %4$s (%1$s)" : "您收到了來自 %4$s (%1$s) 的遠端分享「%3$s」",
    "You received {share} as a remote share from {user}" : "您收到從 {user} 的遠端分享 {share}",
    "Accept" : "接受",
    "Decline" : "拒絕",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "可透過我的 #Nextcloud 聯盟雲端 ID 與我分享，請見 %s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "可透過我的 #Nextcloud 聯盟雲端 ID 與我分享",
    "Sharing" : "分享",
    "Federated file sharing" : "聯盟式檔案分享",
    "Provide federated file sharing across servers" : "提供跨伺服器的聯盟式檔案分享",
    "Federated Cloud Sharing" : "聯盟式雲端分享",
    "Open documentation" : "開啟說明文件",
    "Adjust how people can share between servers. This includes shares between users on this server as well if they are using federated sharing." : "調整人們如何在伺服器間分享。這也包含此伺服器上使用者間的分享，如果他們使用聯盟式分享的話。",
    "Allow users on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "允許此伺服器上的使用者傳送分享到其他伺服器（此選項也允許 WebDAV 存取公開分享）",
    "Allow users on this server to receive shares from other servers" : "允許此伺服器上的使用者接收來自其他伺服器的分享",
    "Allow users on this server to send shares to groups on other servers" : "允許此伺服器上的使用者傳送分享在其他伺服器上的群組",
    "Allow users on this server to receive group shares from other servers" : "允許此伺服氣上的使用者接收來自其他伺服器的群組分享",
    "Search global and public address book for users" : "搜尋全域與公開通訊錄中的使用者",
    "Allow users to publish their data to a global and public address book" : "允許使用者將其資料發佈到全域且公開的通訊錄",
    "Federated Cloud" : "聯盟式雲端",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "您可以與任何使用 Nextcloud 伺服器或其他相容於 Open Cloud Mesh (OCM) 的伺服器與服務分享！只要把他們的雲端聯盟 ID 放在分享對話框中。看起來會像是 person@cloud.example.com",
    "Your Federated Cloud ID:" : "您的雲端聯盟 ID：",
    "Share it so your friends can share files with you:" : "分享它，然後您的朋友就能與您分享檔案：",
    "Add to your website" : "新增至您的網站",
    "Share with me via Nextcloud" : "透過 Nextcloud 與我分享",
    "HTML Code:" : "HTML 程式碼：",
    "Adjust how people can share between servers." : "調整人們如何在伺服器間分享。"
},
"nplurals=1; plural=0;");

==> nextcloud-25.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/zh_TW.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "是否要加入來自 {owner}@{remote} 的遠端分享 {name} ？",
    "Remote share" : "遠端分享",
    "Remote share password" : "遠端分享密碼",
    "Cancel" : "取消",
    "Add remote share" : "新增遠端分享",
    "Invalid Federated Cloud ID" : "無效的雲端聯盟 ID",
    "Server to server sharing is not enabled on this server" : "伺服器對伺服器共享在這台伺服器上面並未啟用",
    "Couldn't establish a federated share." : "無法建立聯盟式分享。",
    "Couldn't establish a federated share, maybe the password was wrong." : "無法建立聯盟式分享，可能是密碼錯誤。",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "已傳送聯盟式分享請求，您將會收到邀請。請檢查您的通知。",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "無法建立聯盟式分享，看來是要聯盟的伺服器太舊了 (Nextcloud <= 9)。",
    "It is not allowed to send federated group shares from this server." : "不允許從此伺服器傳送聯盟式群組分享。",
    "Sharing %1$s failed, because this item is already shared with user %2$s" : "分享 %1$s 失敗，因為此項目已與使用者 %2$s 分享",
    "Not allowed to create a federated share with the same user" : "不允許與同一個使用者建立聯盟式分享",
    "Federated shares require read permissions" : "聯盟分享需要讀取權限",
    "File is already shared with %s" : "檔案已與 %s 分享",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "分享 %1$s 失敗，找不到 %2$s，或許伺服器目前無法存取或使用自行簽署的憑證。",
    "Could not find share" : "找不到分享",
    "Federated sharing" : "聯盟式分享",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "您收到了來自 {user}（代表 {behalf}）的遠端分享 {share}",
    "You received {share} as a remote share from {user}" : "您收到從 {user} 的遠端分享 {share}",
    "Accept" : "接受",
    "Decline" : "拒絕",
    "Federated Cloud Sharing" : "聯盟式雲端分享",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "可透過我的 #Nextcloud 聯盟雲端 ID 與我分享，請見 %s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "可透過我的 #Nextcloud 聯盟雲端 ID 與我分享",
    "Sharing" : "分享",
    "Federated file sharing" : "聯盟式檔案分享",
    "Provide federated file sharing across servers" : "提供跨伺服器的聯盟式檔案分享",
    "Adjust how people can share between servers. This includes shares between users on this server as well if they are using federated sharing." : "調整人們如何在伺服器間分享。這也包含此伺服器上使用者間的分享，如果他們使用聯盟式分享的話。",
    "Allow users on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "允許此伺服器上的使用者傳送分享到其他伺服器（此選項也允許 WebDAV 存取公開分享）",
    "Allow users on this server to receive shares from other servers" : "允許此伺服器上的使用者接收來自其他伺服器的分享",
    "Allow users on this server to send shares to groups on other servers" : "允許此伺服器上的使用者傳送分享在其他伺服器上的群組",
    "Allow users on this server to receive group shares from other servers" : "允許此伺服器上的使用者接收來自其他伺服器的群組分享",
    "Search global and public address book for users" : "搜尋全域與公開通訊錄中的使用者",
    "Allow users to publish their data to a global and public address book" : "允許使用者將其資料發佈到全域且公開的通訊錄",
    "Unable to update federated files sharing config" : "無法更新聯合檔案分享設定",
    "Federated Cloud" : "聯盟式雲端",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "您可以與任何使用 Nextcloud 伺服器或其他相容於 Open Cloud Mesh (OCM) 的伺服器與服務分享！只要把他們的雲端聯盟 ID 放在分享對話框中。看起來會像是 person@cloud.example.com",
    "Your Federated Cloud ID:" : "您的雲端聯盟 ID：",
    "Share it so your friends can share files with you:" : "分享它，然後您的朋友就能與您分享檔案：",
    "Facebook" : "Facebook",
    "Twitter" : "Twitter",
    "Diaspora" : "Diaspora",
    "Add to your website" : "新增至您的網站",
    "Share with me via Nextcloud" : "透過 Nextcloud 與我分享",
    "HTML Code:" : "HTML 程式碼：",
    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "可透過我的 #Nextcloud 聯盟雲端 ID 與我分享，請見 {url}",
    "Cloud ID copied to the clipboard" : "雲端 ID 已複製到剪貼簿",
    "Copy to clipboard" : "複製到剪貼簿",
    "Clipboard is not available" : "剪貼簿無法使用",
    "Copy" : "複製",
    "Copied!" : "已複製！",
    "Not supported!" : "不支援！",
    "Press ⌘-C to copy." : "按下 ⌘-C 以複製。",
    "Press Ctrl-C to copy." : "按下 Ctrl-C 以複製。",
    "You received \"%3$s\" as a remote share from %4$s (%1$s) (on behalf of %5$s (%2$s))" : "您收到了來自 %4$s (%1$s)（代表 %5$s (%2$s)）的遠端分享「%3$s」",
    "You received \"%3$s\" as a remote share from %4$s (%1$s)" : "您收到了來自 %4$s (%1$s) 的遠端分享「%3$s」",
    "Open documentation" : "開啟說明文件"
},
"nplurals=1; plural=0;");
